==> wevue-2.2.3.tgz: package/lib/page.js <==
//转换页面

var fs = require('fs'),
    path = require('path');
var pageFile = null;
var Wxml = require('./wxml');
var Wxss = require('./wxss');
var chalk = require('chalk');
var debug = require('debug')('wevue');

function readFile(wxFolder, page, rootFolder, ext) {
    var file = path.join(wxFolder, page + ext);
    if (fs.existsSync(file)) {
        return fs.readFileSync(file, 'utf8');
    }
    return null;
}

module.exports = function(wxFolder, vueFolder, page, rootFolder, wevueFolder, program, cb) {
    debug("convert", page);
    var pathInfo = path.parse(page);
    var vue = pathInfo.name;

    var folder = path.parse(pathInfo.dir).name;


    debug('page wevueFolder', wevueFolder);
    pageFile = path.join(wevueFolder, `template${program.ver || ''}`, "page.vue");

    var wxml = readFile(wxFolder, page, rootFolder, '.wxml');
    var wxss = readFile(wxFolder, page, rootFolder, '.wxss') || "";
    var js = readFile(wxFolder, page, rootFolder, '.js');
    var json = readFile(wxFolder, page, rootFolder, '.json') || '{}';
    var cdepJs = readFile(wxFolder, page, rootFolder, '.cdep.js');

    var ddep = readFile(wxFolder, page, rootFolder, '.ddep.js');
    var mdep = readFile(wxFolder, page, rootFolder, '.mdep.js');

    if (!wxml) {
        debug(page + '.wxml不存在');
        cb(null, null);
        return;
    }



    Wxml(wxml, program.close, function(err, xml) {
        var template = fs.readFileSync(pageFile, 'utf8');
        var xml = template.replace('{{XML}}', xml).replace('{{WXSS}}', Wxss(wxss));

        /**
         * @lzq添加
         * 替换文件名
         */
        var pageBaseName = path.basename(page)
        xml = xml.replace(/\{\{PAGENAME\}\}/g,pageBaseName)
        /**
         * 是否有cdep文件
         */
        if(!!cdepJs){
            xml = xml.replace(/\{\{PAGECDEP\}\}/g,"require('./"+pageBaseName+".cdep.js')")
        }else{
            xml = xml.replace(/\{\{PAGECDEP\}\}/g,"{}")
        }
        /**
         * 是否有mdep文件
         */
        if(!!mdep){
            xml = xml.replace(/\{\{PAGEMDEP\}\}/g,"require('./"+pageBaseName+".mdep.js')")
        }else{
            xml = xml.replace(/\{\{PAGEMDEP\}\}/g,"{}")
        }
        /**
         * 是否有ddep文件
         */
        if(!!ddep){
            xml = xml.replace(/\{\{PAGEDDEP\}\}/g,"require('./"+pageBaseName+".ddep.js')")
        }else{
            xml = xml.replace(/\{\{PAGEDDEP\}\}/g,"{}")
        }
        //lzq end

        var pageFolder = path.join(vueFolder, 'src', 'pages', folder);
        if (!fs.existsSync(pageFolder)) {
            fs.mkdirSync(pageFolder);
        }

        fs.writeFileSync(path.join(pageFolder, vue + '.vue'), xml);
        if (js) {
            fs.writeFileSync(path.join(pageFolder, vue + '.js'), js);
        }

        if (json) {
            fs.writeFileSync(path.join(pageFolder, vue + '.json'), json);
        }

        if (cdepJs) {
            fs.writeFileSync(path.join(pageFolder, vue + '.cdep.js'), cdepJs);
        }
        if (ddep) {
            fs.writeFileSync(path.join(pageFolder, vue + '.ddep.js'), ddep);
        }
        if (mdep) {
            fs.writeFileSync(path.join(pageFolder, vue + '.cdep.js'), mdep);
        }
        cb(err, null);
    });

}

==> wevue-2.2.4.tgz: package/lib/page.js <==
//转换页面

var fs = require('fs'),
    path = require('path');
var pageFile = null;
var Wxml = require('./wxml');
var Wxss = require('./wxss');
var chalk = require('chalk');
var debug = require('debug')('wevue');

function readFile(wxFolder, page, rootFolder, ext) {
    var file = path.join(wxFolder, page + ext);
    if (fs.existsSync(file)) {
        return fs.readFileSync(file, 'utf8');
    }
    return null;
}

module.exports = function(wxFolder, vueFolder, page, rootFolder, wevueFolder, program, cb) {
    debug("convert", page);
    var pathInfo = path.parse(page);
    var vue = pathInfo.name;

    var folder = path.parse(pathInfo.dir).name;


    debug('page wevueFolder', wevueFolder);
    pageFile = path.join(wevueFolder, `template${program.ver || ''}`, "page.vue");

    var wxml = readFile(wxFolder, page, rootFolder, '.wxml');
    var wxss = readFile(wxFolder, page, rootFolder, '.wxss') || "";
    var js = readFile(wxFolder, page, rootFolder, '.js');
    var json = readFile(wxFolder, page, rootFolder, '.json') || '{}';
    var cdepJs = readFile(wxFolder, page, rootFolder, '.cdep.js');

    var ddep = readFile(wxFolder, page, rootFolder, '.ddep.js');
    var mdep = readFile(wxFolder, page, rootFolder, '.mdep.js');

    if (!wxml) {
        debug(page + '.wxml不存在');
        cb(null, null);
        return;
    }



    Wxml(wxml, program.close, function(err, xml) {
        var template = fs.readFileSync(pageFile, 'utf8');
        var xml = template.replace('{{XML}}', xml).replace('{{WXSS}}', Wxss(wxss));

        /**
         * @lzq添加
         * 替换文件名
         */
        var pageBaseName = path.basename(page)
        xml = xml.replace(/\{\{PAGENAME\}\}/g,pageBaseName)
        /**
         * 是否有cdep文件
         */
        if(!!cdepJs){
            xml = xml.replace(/\{\{PAGECDEP\}\}/g,"require('./"+pageBaseName+".cdep.js')")
        }else{
            xml = xml.replace(/\{\{PAGECDEP\}\}/g,"{}")
        }
        /**
         * 是否有mdep文件
         */
        if(!!mdep){
            xml = xml.replace(/\{\{PAGEMDEP\}\}/g,"require('./"+pageBaseName+".mdep.js')")
        }else{
            xml = xml.replace(/\{\{PAGEMDEP\}\}/g,"{}")
        }
        /**
         * 是否有ddep文件
         */
        if(!!ddep){
            xml = xml.replace(/\{\{PAGEDDEP\}\}/g,"require('./"+pageBaseName+".ddep.js')")
        }else{
            xml = xml.replace(/\{\{PAGEDDEP\}\}/g,"{}")
        }
        //lzq end

        var pageFolder = path.join(vueFolder, 'src', 'pages', folder);
        if (!fs.existsSync(pageFolder)) {
            fs.mkdirSync(pageFolder);
        }

        fs.writeFileSync(path.join(pageFolder, vue + '.vue'), xml);
        if (js) {
            fs.writeFileSync(path.join(pageFolder, vue + '.js'), js);
        }

        if (json) {
            fs.writeFileSync(path.join(pageFolder, vue + '.json'), json);
        }

        if (cdepJs) {
            fs.writeFileSync(path.join(pageFolder, vue + '.cdep.js'), cdepJs);
        }
        if (ddep) {
            fs.writeFileSync(path.join(pageFolder, vue + '.ddep.js'), ddep);
        }
        if (mdep) {
            fs.writeFileSync(path.join(pageFolder, vue + '.mdep.js'), mdep);
        }
        cb(err, null);
    });

}
